@@ -11,6 +11,7 @@ from multiprocessing import Process
 from threading import Thread, Lock
 from Queue import Queue
 import time
+import signal
 
 Gnuplot.GnuplotOpts.prefer_inline_data = 1
 Gnuplot.GnuplotOpts.prefer_fifo_data = 0
@@ -46,7 +47,13 @@ class RTplot():
         t= Thread(target=worker,args=())
         t.setDaemon(True)
         t.start()
-
+    
+    def set_hold(self,on):
+        '''
+        Sets hold state of the plot.
+        takes 0 or 1 as argument
+        '''
+        self.hold = on
     
     def clearFig(self):
         '''
@@ -74,6 +81,8 @@ class RTplot():
         :Parameters:
             -`x`: list of numbers or list of lists
             -`y`: list of numbers or list of lists
+            -`labels`: list of strings (variable names)
+            -`title`: Title of the plot
         """
         assert len(x)==len(y)
         if multiplot:
@@ -241,6 +250,29 @@ class RTplot():
         return 0
 
 
+class AltXMLRPCServer(SimpleXMLRPCServer):
+    '''
+    Subclass of SimpleXMLRPCServer which catches signals at the consoles and terminate the server.
+    thanks http://code.activestate.com/recipes/114579-remotely-exit-a-xmlrpc-server-cleanly/
+    '''
+
+    finished=False
+
+    def register_signal(self, signum):
+        signal.signal(signum, self.signal_handler)
+
+    def signal_handler(self, signum, frame):
+        print "Caught signal", signum
+        self.shutdown()
+
+    def shutdown(self):
+        self.finished=True
+        return 1
+
+    def serve_forever(self):
+        while not self.finished: 
+            self.handle_request()
+
         
 def _start_server(server, persist,hold):
     server.register_instance(RTplot(persist=persist, hold=hold))
@@ -261,8 +293,9 @@ def rpc_plot(port=0, persist=0, hold=0):
             port += 1
             continue
         try:
-            server = SimpleXMLRPCServer(("localhost", port),logRequests=False, allow_none=True)
+            server = AltXMLRPCServer(("localhost", port),logRequests=False, allow_none=True)
             server.register_introspection_functions()
+            server.register_function(server.shutdown)
             p = Process(target=_start_server, args=(server, persist, hold))
            
             #p = Process(target=_start_twisted_server, args=(port, persist))
